==> plasma-framework-5.94.0.tar.xz: plasma-framework-5.94.0/src/desktoptheme/air/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "The Oxygen Project",
                "Name[az]": "Oxygen layihəsi",
                "Name[ca@valencia]": "The Oxygen Project",
                "Name[ca]": "The Oxygen Project",
                "Name[en_GB]": "The Oxygen Project",
                "Name[es]": "El proyecto Oxígeno",
                "Name[eu]": "«Oxygen» proiektua",
                "Name[fr]": "Le projet « Oxygen »",
                "Name[it]": "Il progetto Oxygen",
                "Name[ko]": "The Oxygen Project",
                "Name[nl]": "Het project Oxygen",
                "Name[pl]": "Projekt Tlenu",
                "Name[pt]": "O Projecto Oxygen",
                "Name[sl]": "Projekt kisik",
                "Name[sv]": "Oxygen-projektet",
                "Name[tr]": "Oksijen Projesi",
                "Name[uk]": "Проєкт Oxygen",
                "Name[vi]": "Dự án Oxygen",
                "Name[x-test]": "xxThe Oxygen Projectxx",
                "Name[zh_CN]": "Oxygen 项目"
            }
        ],
        "Category": "",
        "Description": "A breath of fresh air",
        "Description[az]": "Bir nəfəs təmiz hava",
        "Description[ca@valencia]": "Una alenada d'aire fresc",
        "Description[ca]": "Una alenada d'aire fresc",
        "Description[en_GB]": "A breath of fresh air",
        "Description[es]": "Un soplo de aire fresco",
        "Description[eu]": "Haize freskoa arnastea",
        "Description[fr]": "Une bouffée d'air frais",
        "Description[it]": "Una ventata di aria fresca",
        "Description[ko]": "신선한 바람",
        "Description[nl]": "Een hap frisse lucht",
        "Description[pl]": "Powiew świeżego powietrza",
        "Description[pt]": "Uma brisa de ar fresco",
        "Description[sl]": "Vdih svežega zraka",
        "Description[sv]": "Ett friskt andetag",
        "Description[tr]": "Temiz hava",
        "Description[uk]": "Ковток свіжого повітря",
        "Description[vi]": "Một luồng không khí trong lành",
        "Description[x-test]": "xxA breath of fresh airxx",
        "Description[zh_CN]": "如清新空气般淡雅的主题",
        "EnabledByDefault": true,
        "Id": "air",
        "License": "GPL",
        "Name": "Air",
        "Name[az]": "Air",
        "Name[ca@valencia]": "Air",
        "Name[ca]": "Air",
        "Name[cs]": "Vzduch",
        "Name[en_GB]": "Air",
        "Name[es]": "Aire",
        "Name[eu]": "Airea",
        "Name[fr]": "Air",
        "Name[it]": "Aria",
        "Name[ko]": "공기",
        "Name[nl]": "Air",
        "Name[pl]": "Powietrze",
        "Name[pt]": "Ar",
        "Name[sl]": "Zrak",
        "Name[sv]": "Luft",
        "Name[tr]": "Hava",
        "Name[uk]": "Повітря",
        "Name[vi]": "Air",
        "Name[x-test]": "xxAirxx",
        "Name[zh_CN]": "Air 净空",
        "Version": "@KF_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}

==> plasma-framework-5.97.0.tar.xz: plasma-framework-5.97.0/src/desktoptheme/air/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "The Oxygen Project",
                "Name[az]": "Oxygen layihəsi",
                "Name[bg]": "Проектът Oxygen",
                "Name[ca@valencia]": "The Oxygen Project",
                "Name[ca]": "The Oxygen Project",
                "Name[cs]": "Projekt Oxygen",
                "Name[en_GB]": "The Oxygen Project",
                "Name[es]": "El proyecto Oxígeno",
                "Name[eu]": "«Oxygen» proiektua",
                "Name[fi]": "Oxygen-projekti",
                "Name[fr]": "Le projet « Oxygen »",
                "Name[ia]": "Le projecto Oxigen",
                "Name[id]": "The Oxygen Project",
                "Name[it]": "Il progetto Oxygen",
                "Name[ko]": "The Oxygen Project",
                "Name[nl]": "Het project Oxygen",
                "Name[nn]": "Oxygen-prosjektet",
                "Name[pl]": "Projekt Tlenu",
                "Name[pt]": "O Projecto Oxygen",
                "Name[pt_BR]": "O projeto Oxygen",
                "Name[sl]": "Projekt kisik",
                "Name[sv]": "Oxygen-projektet",
                "Name[tr]": "Oksijen Projesi",
                "Name[uk]": "Проєкт Oxygen",
                "Name[vi]": "Dự án Oxygen",
                "Name[x-test]": "xxThe Oxygen Projectxx",
                "Name[zh_CN]": "Oxygen 项目"
            }
        ],
        "Category": "",
        "Description": "A breath of fresh air",
        "Description[az]": "Bir nəfəs təmiz hava",
        "Description[bg]": "Глътка свеж въздух",
        "Description[ca@valencia]": "Una alenada d'aire fresc",
        "Description[ca]": "Una alenada d'aire fresc",
        "Description[cs]": "Závan čerstvého vzduchu",
        "Description[en_GB]": "A breath of fresh air",
        "Description[es]": "Un soplo de aire fresco",
        "Description[eu]": "Haize freskoa arnastea",
        "Description[fi]": "Raikkaan ilman henkäys",
        "Description[fr]": "Une bouffée d'air frais",
        "Description[ia]": "Un respiration de aere fresc",
        "Description[id]": "A breath of fresh air",
        "Description[it]": "Una ventata di aria fresca",
        "Description[ko]": "신선한 바람",
        "Description[nl]": "Een hap frisse lucht",
        "Description[nn]": "Eit friskt pust",
        "Description[pl]": "Powiew świeżego powietrza",
        "Description[pt]": "Uma brisa de ar fresco",
        "Description[sl]": "Vdih svežega zraka",
        "Description[sv]": "Ett friskt andetag",
        "Description[tr]": "Temiz hava",
        "Description[uk]": "Ковток свіжого повітря",
        "Description[vi]": "Một luồng không khí trong lành",
        "Description[x-test]": "xxA breath of fresh airxx",
        "Description[zh_CN]": "如清新空气般淡雅的主题",
        "EnabledByDefault": true,
        "Id": "air",
        "License": "GPL",
        "Name": "Air",
        "Name[az]": "Air",
        "Name[bg]": "Air",
        "Name[ca@valencia]": "Air",
        "Name[ca]": "Air",
        "Name[cs]": "Vzduch",
        "Name[en_GB]": "Air",
        "Name[es]": "Aire",
        "Name[eu]": "Airea",
        "Name[fi]": "Ilma",
        "Name[fr]": "Air",
        "Name[ia]": "Air",
        "Name[id]": "Air",
        "Name[it]": "Aria",
        "Name[ko]": "공기",
        "Name[nl]": "Air",
        "Name[nn]": "Luft",
        "Name[pl]": "Powietrze",
        "Name[pt]": "Ar",
        "Name[pt_BR]": "Air",
        "Name[sl]": "Zrak",
        "Name[sv]": "Luft",
        "Name[tr]": "Hava",
        "Name[uk]": "Повітря",
        "Name[vi]": "Air",
        "Name[x-test]": "xxAirxx",
        "Name[zh_CN]": "Air 净空",
        "Version": "@KF_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}
